Method: Muina::Maybe::None#bind

Defined in:
lib/muina/maybe/none.rb

#bind {|value| ... } ⇒ Maybe

If instance is of the Some variant, it yields the contained value to the block and it returns the return value of the block; if it is of the Muina::Maybe::None variant, it returns itself.

Yield Parameters:

  • value (Elem)

    the contained value is passed to the block

Yield Returns:

Returns:



108
109
110
# File 'lib/muina/maybe/none.rb', line 108

def bind(&_blk)
  self
end